pub(crate) struct TrackedReservation {
reservation: Mutex<Option<Box<dyn MemoryReservation>>>,
}Expand description
This is a wrapper for the reservation so we can standardize on changing and avoid race conditions in memory accounting
Fields
reservation: Mutex<Option<Box<dyn MemoryReservation>>>Implementations
Sourceimpl TrackedReservation
impl TrackedReservation
Sourcepub fn claim(&self, pool: &dyn MemoryPool, capacity: usize)
pub fn claim(&self, pool: &dyn MemoryPool, capacity: usize)
Claim memory from a pool, replacing the current reservation (if exists).
Sourcepub fn resize(&self, new_size: usize)
pub fn resize(&self, new_size: usize)
Resize the memory reservation of this buffer
This is a no-op if this buffer doesn’t have a reservation.