Crate arrow_buffer

Crate arrow_buffer 

Low-level buffer abstractions for Apache Arrow Rust

Byte Storage abstractions

  • MutableBuffer: Raw memory buffer that can be mutated and grown
  • Buffer: Immutable buffer that is shared across threads

Typed Abstractions

There are also several wrappers over Buffer with methods for easier manipulation:

Re-exports

pub use buffer::*;
pub use builder::*;

Modules

alloc
Defines the low-level Allocation API for shared memory regions
bit_chunk_iterator
Types for iterating over bitmasks in 64-bit chunks
bit_iterator
Types for iterating over packed bitmasks
bit_mask
Utils for working with packed bit masks
bit_util
Utils for working with bits
buffer
Types of shared memory region
builder
Buffer builders

Structs

IntervalDayTime
Value of an IntervalDayTime array
IntervalMonthDayNano
Value of an IntervalMonthDayNano array
OverflowError
An arithmetic overflow.
TrackingMemoryPoolpool
A simple MemoryPool that reports the total memory usage
i256
A signed 256-bit integer

Traits

ArrowNativeType
Trait expressing a Rust type that has the same in-memory representation as Arrow.
MemoryPoolpool
A pool of memory that can be reserved and released.
MemoryReservationpool
A memory reservation within a MemoryPool that is freed on drop
ToByteSlice
Allows conversion from supported Arrow types to a byte slice.